<div dir="ltr"><div class="gmail_extra"><br><div class="gmail_quote">On 7 July 2016 at 16:39, Jussi Kukkonen <span dir="ltr"><<a href="mailto:jussi.kukkonen@intel.com" target="_blank">jussi.kukkonen@intel.com</a>></span> wrote:<br><blockquote class="gmail_quote" style="margin:0 0 0 .8ex;border-left:1px #ccc solid;padding-left:1ex"><div id=":6kt" class="a3s aXjCH m155c604d495ea714">A word of warning to anyone else using <span class="il">piglit</span>: it was big before and<br>
has now tripled in size (30000 new tests!). The installed size is over<br>
1.5GB and packaging takes a very long time.<br></div></blockquote></div><br>I did a quick hack to the current piglit in master (poky-contrib:ross/piglit) to strip the binaries. We don't get debug symbols (which are 4gb before the upgrade) and build time on my Xeon drops from 10 minutes to 5 minutes.</div><div class="gmail_extra"><br></div><div class="gmail_extra">I think this is an acceptable compromise!</div><div class="gmail_extra"><br></div><div class="gmail_extra">Ross</div></div>